package com.knauf.ejb.stateless;

import java.io.IOException;
import java.io.PrintWriter;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import javax.servlet.Servlet;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Client-Servlet fr die GeometricModeBean. Es fhrt haargenau die gleiche
 * Logik aus wie die JSP-Seite
 */
public class GeometricModelServlet extends HttpServlet implements Servlet
{
  /*
   * (non-Java-doc)
   * 
   * @see javax.servlet.http.HttpServlet#HttpServlet()
   */
  public GeometricModelServlet()
  {
    super();
  }

  /**
   * Verarbeiten einer HTTP-Anfrage per Post-Methode. Ein POST-Request erfolgt
   * bei jedem Absenden des Formulars (per "action"-Attribut ist die
   * POST-Methode deklariert).
   * 
   * @param request
   *          Der Servlet-Request, mit den Formulardaten.
   * @param response
   *          Die Response, in die HTTP-Ausgabe erfolgt.
   */
  protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
  {
    //Auf diesem PrintWriter erfolgt die Ausgabe der HTML-Seite:
    PrintWriter printWriter = response.getWriter();

    try
    {
      //Ausgabe des Seitenheaders:
      printWriter.write("<HTML>\r\n" + "<HEAD>\r\n" + "<TITLE>GeometricModelTest</TITLE>\r\n"
          + "	<meta http-equiv=\"content-type\" content=\"text/html; charset=Windows-1252\">\r\n" + "</HEAD>\r\n"
          + "<BODY>\r\n" + "<H1>Test fr Stateless Session Bean</H1>\r\n");

      //Soll nur das Formular angezeigt werden oder wurde auf "Berechnen"
      // geklickt ?
      if (request.getParameter("submit") == null)
      {
        //Erster Aufruf: Nur Formular ausgeben.
      }
      else
      {
        // Zweiter bis n-ter Aufruf: Berechnen.

        double dblA = Double.parseDouble(request.getParameter("a"));
        double dblB = Double.parseDouble(request.getParameter("b"));
        double dblC = Double.parseDouble(request.getParameter("c"));

        ///////////////////////////////////////////////////////////////
        // Berechnung ber Remote-Interface.
        InitialContext initialContext = new InitialContext();

        Object homeref = initialContext.lookup("java:comp/env/ejb/GeometricModel");

        GeometricModelHome home = (GeometricModelHome) PortableRemoteObject.narrow(homeref, GeometricModelHome.class);

        GeometricModel geometricModel = home.create();

        double dblVolume = geometricModel.computeCuboidVolume(dblA, dblB, dblC);
        double dblSurface = geometricModel.computeCuboidSurface(dblA, dblB, dblC);

        printWriter.write("Volumen = " + dblVolume + " Oberflche = " + dblSurface + "\r\n"
            + "<br>Und jetzt das ganze ber LocalInterface: \r\n");

        homeref = initialContext.lookup("java:comp/env/ejb/GeometricModelLocal");

        //Local Interfaces knnen direkt ber Typecasts geholt werden.
        GeometricModelLocalHome homeLocal = (GeometricModelLocalHome) homeref;

        GeometricModelLocal geometricModelLocal = homeLocal.create();

        dblVolume = geometricModelLocal.computeCuboidVolume(dblA, dblB, dblC);
        dblSurface = geometricModelLocal.computeCuboidSurface(dblA, dblB, dblC);

        printWriter.write("Volumen = " + dblVolume + ", Oberflche = " + dblSurface + "\r\n" + "<br><br><br>\r\n");
      }

      //Ausgabe des Formulars. Achtung: Das Ziel ist hier hartcodiert, d.h.
      // muss
      //als Alias im Deploytool definiert sein !
      //Es wird automatisch der Pfad des aktuellen Servlets, also
      // "http://localhost:8080/stateless/servlet/"
      //vorangestellt.
      printWriter.write("<form action=\"./GeometricModelServlet\" method=\"post\"> \r\n"
          + "	a = <input type=\"text\" name=\"a\" /> <br> \r\n" + "	b = <input type=\"text\" name=\"b\" /> <br> \r\n"
          + "	c = <input type=\"text\" name=\"c\" /> <br> \r\n"
          + "	<input type=\"submit\" name=\"submit\" value=\"submit\" /> \r\n" + "</form> \r\n" + "</BODY> \r\n"
          + "</HTML> \r\n");
    }
    catch (Exception ex)
    {
      //Ausgabe ins Servlet-Log:
      this.log("Es trat ein Fehler auf: " + ex.getMessage(), ex);
      //Es trat ein Fehler auf: Ausgabe der Meldung.
      printWriter.write("Es trat ein Fehler auf: " + ex.getMessage());
    }

    //Aufrumen:
    printWriter.flush();
    printWriter.close();
  }

  /**
   * Verarbeiten einer HTTP-Anfrage per GET-Request. Wird direkt weitergeleitet
   * an doPost. GET-Requests erfolgen nur beim ersten Aufrufen der Seite.
   * 
   * @param request
   *          Der Servlet-Request, mit den Formulardaten.
   * @param response
   *          Die Response, in die HTTP-Ausgabe erfolgt.
   */
  protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException
  {
    this.doPost(request, response);
  }

}